@@ -3,7 +3,7 @@ from allosaurus.am.utils import *
 import json
 from argparse import Namespace
 
-def read_am(model_path):
+def read_am(model_path, inference_config):
     """
     load pretrained acoustic model
 
@@ -20,4 +20,8 @@ def read_am(model_path):
     # load weights
     torch_load(model, str(model_path / 'model.pt'))
 
+    # move to device
+    if inference_config.device_id >= 0:
+        model = model.cuda(inference_config.device_id)
+
     return model
\ No newline at end of file
